#!/bin/bash
# Tools for Flutter

METHOD="$1"

################################## ROOTER ##################################

function _router() {
  case $METHOD in
  	"clean")   _clean;;
	"build")   _build;;
	"open")   _open;;
	"rebuild")   _rebuild;;
	"rebuild-ios")   _rebuildIOS;;
	"rebuild-android")   _rebuildAndroid;;
  esac
}

function _clean() {
	_cleanPub
	_cleanIOS
	_cleanAndroid
}

function _cleanPub() {
    echo "- Delete the build folder : (rm -rf build/)"
    rm -rf build/
    
	echo "- Delete package-lock.json : (rm pubspec.lock)"
	rm pubspec.lock
}

function _cleanIOS() {
	echo "- Clean Pods folder, Podfile.lock, .xcworkspace : (rm -rf ios/Pods/ && rm -f ios/Podfile.lock && rm -rf ios/*.xcworkspace)"
	rm -rf ios/Pods/ && rm -f ios/Podfile.lock && rm -rf ios/*.xcworkspace
}

function _cleanAndroid() {
	echo "- Clean Android : Nothing"
}

function _build() {
	_buildPub
	_buildIOS
	_buildAndroid
}

function _buildPub() {
	echo "- Installing package : (flutter pub get)"
	flutter pub get
}

function _buildIOS() {
	echo "- Pod update : (pod update)"
	pushd ios
	pod update
	popd
}

function _buildAndroid() {
    echo "- Build Android : Nothing"
}

function _open() {
	_openIOS
	_openAndroid
}

function _openIOS() {
	echo "- Open Xcode : (open ios/*.xcworkspace)"
	open ios/*.xcworkspace
}

function _openAndroid() {
	echo "- Open Android studio : (open -a /Applications/Android\ Studio.app android -g)"
	open -a /Applications/Android\ Studio.app android -g
}

function _rebuild() {
	_clean
	_build
	_open
}

function _rebuildIOS() {
	_cleanPub
	_cleanIOS
	_buildPub
	_buildIOS
	_openIOS
}

function _rebuildAndroid() {
	_cleanPub
	_cleanAndroid
	_buildPub
	_buildAndroid
	_openAndroid
}

_router

echo "-- DONE --"
